[−][src]Struct lamport_sigs::PrivateKey
A one-time signing private key
Methods
impl PrivateKey[src]
pub fn new(algorithm: &'static Algorithm) -> PrivateKey[src]
Generates a new random one-time signing key. This method can panic if OS RNG fails
pub fn public_key(&self) -> PublicKey[src]
Returns the public key associated with this private key
pub fn sign(&mut self, data: &[u8]) -> Result<Vec<Vec<u8>>, &'static str>[src]
Signs the data with the private key and returns the result if successful. If unsuccesful, an explanation string is returned